@@ -28,6 +28,7 @@ from awkward._typing import (
     Any,
     Callable,
     Final,
+    Literal,
     Self,
     SupportsIndex,
     final,
@@ -652,13 +653,18 @@ class RecordArray(RecordMeta[Content], Content):
                 ),
             )
 
-    def _mergeable_next(self, other: Content, mergebool: bool) -> bool:
+    def _mergeable_next(
+        self,
+        other: Content,
+        mergebool: bool,
+        mergecastable: Literal["same_kind", "equiv", "family"],
+    ) -> bool:
         # Is the other content is an identity, or a union?
         if other.is_identity_like or other.is_union:
             return True
         # Check against option contents
         elif other.is_option or other.is_indexed:
-            return self._mergeable_next(other.content, mergebool)
+            return self._mergeable_next(other.content, mergebool, mergecastable)
         # Otherwise, do the parameters match? If not, we can't merge.
         elif not type_parameters_equal(self._parameters, other._parameters):
             return False
@@ -666,7 +672,9 @@ class RecordArray(RecordMeta[Content], Content):
             if self.is_tuple and other.is_tuple:
                 if len(self._contents) == len(other._contents):
                     for self_cont, other_cont in zip(self._contents, other._contents):
-                        if not self_cont._mergeable_next(other_cont, mergebool):
+                        if not self_cont._mergeable_next(
+                            other_cont, mergebool, mergecastable
+                        ):
                             return False
 
                     return True
@@ -678,7 +686,7 @@ class RecordArray(RecordMeta[Content], Content):
                 for i, field in enumerate(self._fields):
                     x = self._contents[i]
                     y = other._contents[other.field_to_index(field)]
-                    if not x._mergeable_next(y, mergebool):
+                    if not x._mergeable_next(y, mergebool, mergecastable):
                         return False
                 return True
 
@@ -1044,9 +1052,10 @@ class RecordArray(RecordMeta[Content], Content):
             return out
 
     def _validity_error(self, path):
-        for i, cont in enumerate(self.contents):
-            if cont.length < self.length:
-                return f"at {path} ({type(self)!r}): len(field({i})) < len(recordarray)"
+        if self._backend.nplike.known_data:
+            for i, cont in enumerate(self.contents):
+                if cont.length < self.length:
+                    return f"at {path} ({type(self)!r}): len(field({i})) < len(recordarray)"
         for i, cont in enumerate(self.contents):
             sub = cont._validity_error(f"{path}.field({i})")
             if sub != "":
